
package io.fabric8.swagger.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.validation.Valid;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import lombok.EqualsAndHashCode;
import lombok.ToString;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "method",
    "summary",
    "notes",
    "nickname",
    "authorizations",
    "parameters",
    "responseMessages",
    "produces",
    "consumes",
    "deprecated"
})
@ToString
@EqualsAndHashCode
public class OperationObjectJson {

    @JsonProperty("method")
    private OperationObjectJson.Method method;
    @JsonProperty("summary")
    @Size(max = 120)
    private String summary;
    @JsonProperty("notes")
    private String notes;
    @JsonProperty("nickname")
    @Pattern(regexp = "^[a-zA-Z0-9_]+$")
    private String nickname;
    @JsonProperty("authorizations")
    @Valid
    private Authorizations authorizations;
    @JsonProperty("parameters")
    @Valid
    private List<ParameterObjectJson> parameters = new ArrayList<ParameterObjectJson>();
    @JsonProperty("responseMessages")
    @Valid
    private List<ResponseMessageObject> responseMessages = new ArrayList<ResponseMessageObject>();
    @JsonProperty("produces")
    @JsonDeserialize(as = java.util.LinkedHashSet.class)
    @Valid
    private Set<String> produces = new LinkedHashSet<String>();
    @JsonProperty("consumes")
    @JsonDeserialize(as = java.util.LinkedHashSet.class)
    @Valid
    private Set<String> consumes = new LinkedHashSet<String>();
    @JsonProperty("deprecated")
    private OperationObjectJson.Deprecated deprecated;
    @JsonIgnore
    @Valid
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    @JsonProperty("method")
    public OperationObjectJson.Method getMethod() {
        return method;
    }

    @JsonProperty("method")
    public void setMethod(OperationObjectJson.Method method) {
        this.method = method;
    }

    @JsonProperty("summary")
    public String getSummary() {
        return summary;
    }

    @JsonProperty("summary")
    public void setSummary(String summary) {
        this.summary = summary;
    }

    @JsonProperty("notes")
    public String getNotes() {
        return notes;
    }

    @JsonProperty("notes")
    public void setNotes(String notes) {
        this.notes = notes;
    }

    @JsonProperty("nickname")
    public String getNickname() {
        return nickname;
    }

    @JsonProperty("nickname")
    public void setNickname(String nickname) {
        this.nickname = nickname;
    }

    @JsonProperty("authorizations")
    public Authorizations getAuthorizations() {
        return authorizations;
    }

    @JsonProperty("authorizations")
    public void setAuthorizations(Authorizations authorizations) {
        this.authorizations = authorizations;
    }

    @JsonProperty("parameters")
    public List<ParameterObjectJson> getParameters() {
        return parameters;
    }

    @JsonProperty("parameters")
    public void setParameters(List<ParameterObjectJson> parameters) {
        this.parameters = parameters;
    }

    @JsonProperty("responseMessages")
    public List<ResponseMessageObject> getResponseMessages() {
        return responseMessages;
    }

    @JsonProperty("responseMessages")
    public void setResponseMessages(List<ResponseMessageObject> responseMessages) {
        this.responseMessages = responseMessages;
    }

    @JsonProperty("produces")
    public Set<String> getProduces() {
        return produces;
    }

    @JsonProperty("produces")
    public void setProduces(Set<String> produces) {
        this.produces = produces;
    }

    @JsonProperty("consumes")
    public Set<String> getConsumes() {
        return consumes;
    }

    @JsonProperty("consumes")
    public void setConsumes(Set<String> consumes) {
        this.consumes = consumes;
    }

    @JsonProperty("deprecated")
    public OperationObjectJson.Deprecated getDeprecated() {
        return deprecated;
    }

    @JsonProperty("deprecated")
    public void setDeprecated(OperationObjectJson.Deprecated deprecated) {
        this.deprecated = deprecated;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

    public enum Deprecated {

        TRUE("true"),
        FALSE("false");
        private final String value;
        private final static Map<String, OperationObjectJson.Deprecated> CONSTANTS = new HashMap<String, OperationObjectJson.Deprecated>();

        static {
            for (OperationObjectJson.Deprecated c: values()) {
                CONSTANTS.put(c.value, c);
            }
        }

        private Deprecated(String value) {
            this.value = value;
        }

        @Override
        public String toString() {
            return this.value;
        }

        @JsonValue
        public String value() {
            return this.value;
        }

        @JsonCreator
        public static OperationObjectJson.Deprecated fromValue(String value) {
            OperationObjectJson.Deprecated constant = CONSTANTS.get(value);
            if (constant == null) {
                throw new IllegalArgumentException(value);
            } else {
                return constant;
            }
        }

    }

    public enum Method {

        GET("GET"),
        HEAD("HEAD"),
        POST("POST"),
        PUT("PUT"),
        PATCH("PATCH"),
        DELETE("DELETE"),
        OPTIONS("OPTIONS");
        private final String value;
        private final static Map<String, OperationObjectJson.Method> CONSTANTS = new HashMap<String, OperationObjectJson.Method>();

        static {
            for (OperationObjectJson.Method c: values()) {
                CONSTANTS.put(c.value, c);
            }
        }

        private Method(String value) {
            this.value = value;
        }

        @Override
        public String toString() {
            return this.value;
        }

        @JsonValue
        public String value() {
            return this.value;
        }

        @JsonCreator
        public static OperationObjectJson.Method fromValue(String value) {
            OperationObjectJson.Method constant = CONSTANTS.get(value);
            if (constant == null) {
                throw new IllegalArgumentException(value);
            } else {
                return constant;
            }
        }

    }

}
